@@ -1,14 +1,10 @@
 package Dist::Zilla::Plugin::Test::Version;
-use 5.006;
-use strict;
-use warnings;
-use namespace::autoclean;
-
-our $VERSION = '1.06'; # VERSION
 
 use Moose;
-extends 'Dist::Zilla::Plugin::InlineFiles';
+
 with
+  'Dist::Zilla::Role::FileGatherer',
+  'Dist::Zilla::Role::FileMunger',
   'Dist::Zilla::Role::TextTemplate',
   'Dist::Zilla::Role::PrereqSource',
   'Dist::Zilla::Role::FileFinderUser' => {
@@ -18,9 +14,36 @@ with
   },
 ;
 
+use Sub::Exporter::ForMethods 'method_installer';
+use Data::Section 0.004 # fixed header_re
+    { installer => method_installer }, '-setup';
+use Moose::Util::TypeConstraints qw( role_type union enum );
+use namespace::autoclean;
 
-around add_file => sub {
-  my ( $orig, $self, $file ) = @_;
+# ABSTRACT: Author Test::Version tests
+our $VERSION = '1.07'; # VERSION
+
+sub gather_files {
+  my($self) = @_;
+
+  require Dist::Zilla::File::InMemory;
+
+  $self->add_file(
+    $self->_file_obj(
+      Dist::Zilla::File::InMemory->new(
+        # PRs welcome: make configurable.
+        name => 'xt/author/test-version.t',
+        content => ${$self->section_data('__TEST__')},
+      )
+    )
+  );
+
+  return;
+}
+
+sub munge_files
+{
+  my($self) = @_;
 
   my @filenames;
   my $use_finder = 0;
@@ -32,27 +55,27 @@ around add_file => sub {
     $use_finder = 1;
   }
 
-  $self->$orig(
-    Dist::Zilla::File::InMemory->new({
-      name    => $file->name,
-      content => $self->fill_in_string(
-        $file->content,
-        {
-          name           => __PACKAGE__,
-          version        => __PACKAGE__->VERSION
-            || 'bootstrapped version'
-            ,
-          is_strict      => \$self->is_strict,
-          has_version    => \$self->has_version,
-          multiple       => \$self->multiple,
-          filename_match => join(", ", @{ $self->filename_match }),
-          filenames      => [ sort @filenames ],
-          use_finder     => $use_finder,
-        },
-      ),
-    })
+  my $file = $self->_file_obj;
+  $file->content(
+    $self->fill_in_string(
+      $file->content,
+      {
+        name           => __PACKAGE__,
+        version        => __PACKAGE__->VERSION
+          || 'bootstrapped version'
+          ,
+        is_strict      => \$self->_is_strict,
+        has_version    => \$self->has_version,
+        multiple       => \$self->multiple,
+        filename_match => join(", ", @{ $self->filename_match }),
+        filenames      => [ sort @filenames ],
+        use_finder     => $use_finder,
+      },
+    )
   );
-};
+
+  return;
+}
 
 sub register_prereqs {
   my $self = shift;
@@ -67,10 +90,20 @@ sub register_prereqs {
 }
 
 has is_strict => (
+  is      => 'ro',
+  isa     => union([ 'Bool', enum(['adaptive']) ]),
+  lazy    => 1,
+  default => sub { 0 },
+);
+
+has _is_strict => (
   is => 'ro',
   isa => 'Bool',
   lazy => 1,
-  default => sub { 0 },
+  default => sub {
+    my($self) = @_;
+    $self->is_strict eq 'adaptive' ? ($self->zilla->is_trial ? 0 : 1) : $self->is_strict
+  },
 );
 
 has has_version => (
@@ -94,6 +127,11 @@ has filename_match => (
   default => sub { [] },
 );
 
+has _file_obj => (
+  is  => 'rw',
+  isa => role_type('Dist::Zilla::Role::File'),
+);
+
 around mvp_multivalue_args => sub {
   my($orig, $self) = @_;
   return ($self->$orig, 'filename_match');
@@ -102,8 +140,6 @@ around mvp_multivalue_args => sub {
 __PACKAGE__->meta->make_immutable;
 1;
 
-# ABSTRACT: Author Test::Version tests
-
 =pod
 
 =head1 NAME
@@ -112,7 +148,7 @@ Dist::Zilla::Plugin::Test::Version - Author Test::Version tests
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -132,6 +168,10 @@ This module will add a L<Test::Version> test as a author test to your module.
 
 set L<Test::Version is_strict|Test::Version/is_strict>
 
+In addition to a boolean value, you may specify C<adaptive> to indicate that
+is_strict should be true for production releases, but false for trial or
+development releases.
+
 =head2 has_version
 
 set L<Test::Version has_version|Test::Version/has_version>
@@ -191,7 +231,7 @@ This is free software, licensed under:
 =cut
 
 __DATA__
-__[ xt/author/test-version.t ]__
+__[ __TEST__ ]__
 use strict;
 use warnings;
 use Test::More;
